=======
History
=======

0.0.4 (2017-07-13)
------------------

* add hands free alexa util using respeaker python library

0.0.3 (2017-07-11)
------------------

* use gstreamer to play audio stream
* support dueros avs compatible service
* many improments

0.0.2 (2017-07-05)
------------------

* rename alexa util to alexa-tap
* add oauth util alexa-auth

0.0.1 (2017-07-04)
------------------

* First release on PyPI.
